@@ -46,7 +46,8 @@ def format_setting_value(value):
     import json
     import logging
     formatted_value = value
-    if isinstance(value, str) and (any([i in value for i in ['"', '[', '{']]) or value.lower() in ['true', 'false']):
+    if isinstance(value, str) and (
+            any([i in value for i in ['"', '[', '{']]) or value.lower() in ['true', 'false'] or value.isdigit()):
         try:
             formatted_value = json.loads(value)
         except json.JSONDecodeError as exc:
